from pipelex.system.exceptions import ToolException


class SecretNotFoundError(ToolException):
    pass
